@@ -23,9 +23,37 @@ class SimpleHook:
         self.webhook_url = webhook_url
 
     def __post(self, **kwargs) -> None:
+        """
+        Helper method to send a POST request.
+
+        Args:
+            **kwargs: Arbitrary keyword arguments passed to the underlying HTTP request (e.g., json, headers).
+
+        Raises:
+            HTTPError: If the HTTP request returns an unsuccessful status code.
+        """
+
         r = requests.post(url=self.webhook_url, **kwargs)
         r.raise_for_status()
 
+    def __validate(self, color: int) -> int:
+        """
+        Validate the color value to ensure it is within the allowed range.
+
+        Args:
+            color (int): The color value to validate. Must be between 0 and 65280 inclusive.
+
+        Returns:
+            int: The validated color value if it is within the valid range.
+
+        Raises:
+            ValueError: If the color value is outside the range 0 to 65280.
+        """
+        if color < 0 or color > 65280:
+            raise ValueError("Value of color must be between 0 and 65280!")
+        else:
+            return color
+
     def send_message(self, message: str) -> None:
         """
         Send a basic text message to the Discord webhook.
@@ -74,23 +102,23 @@ class SimpleHook:
 
             if mention == "everyone" or mention == "here":
                 body['content'] = f"@{mention} {message}"
-        
+
         if tts:
             body["tts"] = tts
 
         self.__post(json=body)
 
-    def send_file(self, image_path: str) -> None:
+    def send_file(self, file_path: str) -> None:
         """
         Send a single file via the Discord webhook.
 
         Args:
-            image_path (str): The local path to the file.
+            file_path (str): The local path to the file.
         """
 
-        with open(image_path, "rb") as f:
+        with open(file_path, "rb") as f:
             file = f.read()
-            filename = os.path.basename(image_path)
+            filename = os.path.basename(file_path)
 
         file_body: dict = {
             "file": (filename, file)
@@ -98,13 +126,14 @@ class SimpleHook:
 
         self.__post(files=file_body)
 
-    def send_embedded_images(self, paths: list[str], message: Optional[str] = None) -> None:
+    def send_embedded_files(self, paths: list[str], message: Optional[str] = None, color: Optional[int] = None) -> None:
         """
         Send multiple files as embedded content in a Discord message.
 
         Args:
             paths (list[str]): List of local file paths to send (maximum 10 files).
             message (Optional[str]): Optional text content to include with the embeds.
+            color (Optional[int], optional): Decimal integer color value between 0 and 65280. Defaults to None.
 
         Raises:
             ValueError: If more than 10 files are provided.
@@ -124,6 +153,9 @@ class SimpleHook:
                 embeds.append({
                     "image": {"url": f"attachment://"+filename}
                 })
+            if color is not None:
+                color = self.__validate(color)
+                embeds[index]["color"] = color
 
         payload = {
             "content": message or "",
@@ -199,4 +231,95 @@ class SimpleHook:
                 raise ValueError(
                     "Length of emojis must match length of answers")
 
+        self.__post(json=body)
+
+    def send_embedded_message(self, title: str, color: Optional[int] = None) -> None:
+        """Send an embedded message.
+
+        Args:
+            title (str): Content of the embed.
+            color (Optional[int], optional): Decimal integer color value between 0 and 65280. Defaults to None.
+        """
+
+        body = {
+            "embeds": []
+        }
+
+        body["embeds"].append({"title": title})
+
+        if color is not None:
+            color = self.__validate(color)
+            body["embeds"][0]["color"] = color
+
+        self.__post(json=body)
+
+    def send_embedded_author(self, name: str, avatar_url: str, url: Optional[str] = None,  description: Optional[str] = None, color: Optional[int] = None) -> None:
+        """Send an embedded author message.
+
+        Args:
+            name (str): Name of the author.
+            url (str): URL for the hyperlink.
+            avatar_url (str): Image URL for the author's avatar.
+            description (Optional[str], optional): Description content of the message. Defaults to None.
+            color (Optional[int], optional): Decimal integer color value between 0 and 65280. Defaults to None.
+        """
+
+        author = {"name": name, "icon_url": avatar_url}
+        body = {
+            "embeds": []
+        }
+        body["embeds"].append({"author": author})
+
+        if url is not None:
+            body["embeds"][0]["author"]["url"] = url
+
+        if description is not None:
+            body["embeds"][0]["description"] = description
+
+        if color is not None:
+            color = self.__validate(color)
+            body["embeds"][0]["color"] = color
+
+        self.__post(json=body)
+
+    def send_embedded_url(self, title: str, url: str, color: Optional[int] = None) -> None:
+        """Send an embedded message with a hyperlink.
+
+        Args:
+            title (str): Content of the embed.
+            url (str): URL for the hyperlink.
+            color (Optional[int], optional): Decimal integer color value between 0 and 65280. Defaults to None.
+        """
+
+        body = {
+            "embeds": []
+        }
+
+        body["embeds"].append({"title": title, "url": url})
+
+        if color is not None:
+            color = self.__validate(color)
+            body["embeds"][0]["color"] = color
+
+        self.__post(json=body)
+
+    def send_embedded_url_image(self, url: str,message: Optional[str] = None, color: Optional[int] = None) -> None:
+        """Send an embedded image via URL.
+
+        Args:
+            url (str): URL of the image.
+            color (Optional[int], optional): Decimal integer color value between 0 and 65280. Defaults to None.
+        """
+
+        body = {
+            "embeds": [],
+            "content": message or ""
+        }
+
+        body["embeds"].append({"image": {"url": url}})
+
+        if color is not None:
+            color = self.__validate(color)
+            body["embeds"][0]["color"] = color
+
         self.__post(json=body)
\ No newline at end of file
